# -*- coding: utf-8 -*-

#
# furl - URL manipulation made simple.
#
# Ansgar Grunseid
# grunseid.com
# grunseid@gmail.com
#
# License: Build Amazing Things (Unlicense)
#

from .furl import *  # noqa
from .__version__ import (  # noqa
    __title__, __version__, __license__, __author__, __contact__, __url__,
    __description__)
